@@ -56,6 +56,7 @@ from meshed.base import ch_func_node_attrs
 from meshed.itools import parents, children
 
 
+# TODO: Lot's of cleaning and simplification needed in this module!!!
 def simple_namer(name, *, prefix='', suffix=''):
     return f'{prefix}{name}{suffix}'
 
@@ -159,6 +160,18 @@ def crudify_func_nodes(
     )
 
 
+def crudify_funcs(
+    var_nodes: Union[str, Iterable[str]],
+    dag: DAG,  # TODO: Postelize. Accept func_nodes and funcs
+    var_node_name_to_store_name=partial(simple_namer, suffix='_store'),
+    *,
+    mall: Union[Mapping[str, Mapping[str, Any]], None] = None,
+    include_stores_attribute: bool = False,
+    save_name_param: str = 'save_name',
+):
+    return list(_crudified_funcs(**locals()))
+
+
 class VarNodeRole(Enum):
     """(Var)Node roles.
 
@@ -273,7 +286,7 @@ def _func_nodes_arg_and_return_names_to_crude(
     ...     y = bar(x, greeting)
     ...     z = confuser(a, w=x)  # note the w=x to test non-trivial binding
     >>>
-    >>> # Showing but skipping (because I can't get order to be stable (TODO: Make it so)
+    >>> # Showing but skipping (because can't get order to be stable (TODO: Make it so)
     >>> sorted(
     ... _func_nodes_arg_and_return_names_to_crude(['x', 'a'], dag)
     ... )  # doctest: +SKIP
@@ -347,16 +360,24 @@ def _crudified_func_nodes(
     mall: Union[Mapping[str, Mapping[str, Any]], None] = None,
     include_stores_attribute: bool = False,
     save_name_param: str = 'save_name',
+    remove_save_name=True,  # TODO: should be False or not exist
 ):
     if isinstance(var_nodes, str):
         var_nodes = var_nodes.split()
-    # make a mall for all the var_names, giving them all empty dicts as stores if they are not there already.
-    mall = mall or dict()
+    # make a mall for all the var_names, giving them all empty dicts as stores
+    # if they are not there already.
+    if mall is None:
+        mall = defaultdict(dict)
+
+    # TODO: This overwrites the mall outside so user is surprised!
     mall = dict(
         {var_node_name_to_store_name(var_name): dict() for var_name in var_nodes},
         **mall,
     )
-    rm_save_name = partial(rm_params, params_to_remove=[save_name_param])
+    if remove_save_name:
+        rm_save_name = partial(rm_params, params_to_remove=[save_name_param])
+    else:
+        rm_save_name = lambda x: x
 
     for (
         func_node,
@@ -394,6 +415,20 @@ def _crudified_func_nodes(
             yield ch_func_node_attrs(func_node, func=rm_save_name(crudified_func))
 
 
+def _crudified_funcs(
+    var_nodes: Union[str, Iterable[str]],
+    dag: DAG,
+    var_node_name_to_store_name=partial(simple_namer, suffix='_store'),
+    *,
+    mall: Union[Mapping[str, Mapping[str, Any]], None] = None,
+    include_stores_attribute: bool = False,
+    save_name_param: str = 'save_name',
+):
+    kwargs = dict(locals(), remove_save_name=False)
+    func_nodes = _crudified_func_nodes(**kwargs)
+    yield from (fn.func for fn in func_nodes)
+
+
 # empty_name_callback: Callable[[], Any] = None,
 # auto_namer: Callable[..., str] = None,
 # output_trans: Callable[..., Any] = None,
