@@ -25,9 +25,10 @@ formula1(w=1, x=2.0, z=1, y=1)
 from typing import Callable, Any
 from functools import partial
 
-from pydantic import create_model
+from pydantic import create_model, BaseModel
+
 from i2 import Sig, name_of_obj, empty_param_attr
-from i2.wrapper import wrap
+from i2.wrapper import wrap, Ingress
 
 
 def pyd_func_ingress_template(input_model_instance, wrapped_func_sig: Sig):
@@ -52,10 +53,64 @@ def func_to_pyd_func(func: Callable, dflt_type=Any):
     return wrap(func, ingress=pyd_func_ingress)
 
 
-def func_to_pyd_input_model_cls(func: Callable, dflt_type=Any, name=None):
-    """Get a pydantic model of the arguments of a python function"""
+def func_to_pyd_input_model_cls(
+    func: Callable, dflt_type=Any, *, name=None, warn_when_changing_names=True
+):
+    """Get a pydantic model of the arguments of a python function
+
+    >>> def foo(a, b: int, c: bool=False):
+    ...     ...
+    >>> obj = func_to_pyd_input_model_cls(foo)
+    >>> import json
+    >>> assert json.loads(obj.schema_json()) == (
+    ... {
+    ...     'title': 'foo',
+    ...     'type': 'object',
+    ...     'properties': {
+    ...         'a': {'title': 'A'},
+    ...         'b': {'title': 'B', 'type': 'integer'},
+    ...         'c': {'title': 'C', 'default': False, 'type': 'boolean'}
+    ...     },
+    ...     'required': ['a', 'b']
+    ... })
+
+    If some argument names of the function conflict with attribute names of BaseModel,
+    these will be capitalized to resolve the conflict.
+
+    >>> def bar(x, copy, schema):
+    ...     ...
+    >>> obj2 = func_to_pyd_input_model_cls(bar, warn_when_changing_names=False)
+    >>> assert json.loads(obj2.schema_json()) == (
+    ... {
+    ...     'title': 'bar',
+    ...     'type': 'object',
+    ...     'properties': {
+    ...         'x': {'title': 'X'},
+    ...         'COPY': {'title': 'Copy'},
+    ...         'SCHEMA': {'title': 'Schema'}},
+    ...     'required': ['x', 'COPY', 'SCHEMA']
+    ... })
+
+    """
     name = name or name_of_obj(func)
-    return create_model(name, **dict(func_to_pyd_model_specs(func, dflt_type)))
+    try:
+        return create_model(name, **dict(func_to_pyd_model_specs(func, dflt_type)))
+    except NameError:
+        conflicting_names = set(Sig(func).names) & set(dir(BaseModel))
+        old_to_new_names = {k: k.upper() for k in conflicting_names}
+        if warn_when_changing_names:
+            from warnings import warn
+
+            warn(
+                f'''{len(conflicting_names)} argument name(s) conflicted with BaseModel.
+            They're being replaced with upper-case names to resolve conflict. old:new ->
+            {old_to_new_names}
+            '''
+            )
+        wrapped_func = Ingress.name_map(func, **old_to_new_names).wrap(func)
+        return create_model(
+            name, **dict(func_to_pyd_model_specs(wrapped_func, dflt_type))
+        )
 
 
 def func_to_pyd_model_specs(func: Callable, dflt_type=Any):
@@ -80,10 +135,6 @@ def pydantic_egress(output):
     return mod(output_val=output)
 
 
-from front.py2pydantic import func_to_pyd_input_model_cls
-from pydantic import create_model
-
-
 def pydantic_model_from_type(mytype, name='Output', field_name='result'):
     model = create_model(name, **{field_name: (mytype, ...)})
 
